@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Cache;
-$Weather::OpenWeatherMap::Cache::VERSION = '0.004001';
+$Weather::OpenWeatherMap::Cache::VERSION = '0.005001';
 use Carp;
 use strictures 2;
 
@@ -39,6 +39,18 @@ has expiry => (
 
 ## FIXME max_entries ? or a size limit ?
 
+sub serialize {
+  my ($self, $obj) = @_;
+  Storable::freeze(
+    [ Time::HiRes::time, $obj ]
+  )
+}
+
+sub deserialize {
+  my ($self, $data) = @_;
+  Storable::thaw($data)
+}
+
 sub make_path {
   my ($self, $obj) = @_;
 
@@ -50,7 +62,7 @@ sub make_path {
     unless blessed($obj) and $obj->isa('Weather::OpenWeatherMap::Request');
 
   my $fname = 'W';
-  # also see cache_paths
+  # also see cache_paths; new cache prefixes need added there also
   TYPE: {
     if ($obj->isa('Weather::OpenWeatherMap::Request::Current')) {
       $fname .= 'C';
@@ -76,16 +88,9 @@ sub make_path {
   path( join '/', $self->dir->absolute, $fname )
 }
 
-
-sub serialize {
-  my ($self, $obj) = @_;
-  Storable::freeze(
-    [ Time::HiRes::time, $obj ]
-  )
-}
-
 sub cache {
   my ($self, @results) = @_;
+  my $count = 0;
   for my $result (@results) {
     confess "Expected a Weather::OpenWeatherMap::Result but got $result"
       unless blessed($result) 
@@ -95,30 +100,48 @@ sub cache {
     my $path   = $self->make_path($request);
     my $frozen = $self->serialize($result);
     $path->spew_raw($frozen);
+    ++$count;
   }
-  1
+  $count
 }
 
 sub is_cached {
-  my ($self, $obj) = @_;
-  my $path = $self->make_path($obj);
+  my ($self, $request) = @_;
+  my $path = $self->make_path($request);
   return unless $path->exists;
-  return if $self->expire($obj);
+  return if $self->expire($request);
   $path
 }
 
-sub deserialize {
-  my ($self, $data) = @_;
-  Storable::thaw($data)
-}
-
 sub retrieve {
-  my ($self, $obj) = @_;
-  my $path = $self->is_cached($obj);
+  my ($self, $request) = @_;
+
+  my $path = $self->is_cached($request);
   return unless $path;
+
   my $data = $path->slurp_raw;
-  my $ref = $self->deserialize($data);
+  my $ref =
+    try { $self->deserialize($data) }
+    catch {
+      warn "deserialize died on retrieve: $_\n";
+      warn "Attempting to remove possibly corrupt cachefile: $path";
+      $path->remove;
+      undef
+    };
+  return unless $ref;
+
   my ($ts, $result) = @$ref;
+  unless (defined $ts && defined $result) {
+    warn "cachefile incomplete, removing: $path";
+    $path->remove;
+    return
+  }
+
+  # cached Request obj attached to Result may be stale
+  # (e.g. tag may be different for new Request/Result pair)
+  # FIXME tests for this are lacking
+  $result->set_request($request);
+
   hash(
     cached_at => $ts,
     object    => $result
@@ -135,11 +158,18 @@ sub expire {
   my $ref = 
     try { $self->deserialize($data) }
     catch {
+      warn "deserialize died on expiry check: $_\n";
       warn "Attempting to remove possibly corrupt cachefile: $path";
-      $path->remove
+      $path->remove;
+      undef
     };
+  return unless $ref;
 
   my ($ts) = @$ref;
+  unless ($ts) {
+    warn "expiring possibly corrupt cachefile: $path";
+    return $path->remove
+  }
   return $path->remove if Time::HiRes::time - $ts > $self->expiry;
   ()
 }
@@ -221,10 +251,12 @@ C<1200>.
 Takes a list of L<Weather::OpenWeatherMap::Result> objects and caches to
 L</dir>.
 
+Returns the number of items cached.
+
 =head4 retrieve
 
 Takes a L<Weather::OpenWeatherMap::Request> and attempts to retrieve a
-(non-expired) cached result.
+(non-expired) cached L<Weather::OpenWeatherMap::Result>.
 
 Returns false if no item was found.
 
