@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result::Find;
-$Weather::OpenWeatherMap::Result::Find::VERSION = '0.004001';
+$Weather::OpenWeatherMap::Result::Find::VERSION = '0.005001';
 use Carp;
 use strictures 2;
 
@@ -49,7 +49,10 @@ has _list => (
 sub count    { shift->_list->count }
 sub list     { shift->_list->all }
 sub as_array { array(shift->_list->all) }
-sub iter     { shift->_list->natatime(1) }
+sub iter {
+  my ($self, $count) = @_;
+  $self->_list->natatime($count || 1)
+}
 
 
 1;
