@@ -1,5 +1,5 @@
 package Weather::OpenWeatherMap::Result::Forecast::Hour;
-$Weather::OpenWeatherMap::Result::Forecast::Hour::VERSION = '0.004001';
+$Weather::OpenWeatherMap::Result::Forecast::Hour::VERSION = '0.005001';
 use strictures 2;
 
 use Types::Standard      -all;
@@ -118,7 +118,7 @@ has _snow => (
   builder     => sub { +{ '3h' => 0 } },
 );
 
-sub snow { shift->_snow->{'3h'} // 0 }
+sub snow { 0 + sprintf '%.1f', shift->_snow->{'3h'} // 0 }
 
 has _rain => (
   init_arg    => 'rain',
@@ -129,7 +129,7 @@ has _rain => (
   builder     => sub { +{ '3h' => 0 } },
 );
 
-sub rain { shift->_rain->{'3h'} // 0 }
+sub rain { 0 + sprintf '%.1f', shift->_rain->{'3h'} // 0 }
 
 
 with 'Weather::OpenWeatherMap::Result::Forecast::Block';
